import { ActiveHashRecord, Queryable } from "activehashie";
import { ValidationMethods } from "./validation_methods";
/** バリデーションエラーレポート */
export interface ValidationErrorReport<Record extends ActiveHashRecord> {
    /** モデル */
    model: Queryable<Record>;
    /** カラム */
    column?: keyof Record;
    /** ID */
    ids?: number[];
    /** エラーメッセージ */
    message: string;
}
/** バリデーションエラーレポート群 */
export declare type ValidationErrorReports = Array<ValidationErrorReport<any>>;
/** バリデーションを記述する関数 */
export declare type ValidationsFunction<Record extends ActiveHashRecord> = 
/**
 * @param v 汎用のvalidatesメソッドとカスタム定義のvalidateメソッド
 */
(v: ValidationMethods<Record>) => void;
/**
 * バリデーション情報を管理する
 */
export declare class ActiveHashValidation {
    /** バリデートで検出されたエラー */
    errors: ValidationErrorReports;
    /** コンストラクタ */
    constructor();
    /**
     * モデルをバリデートする
     * @param model モデル
     * @param validations バリデーションを記述する関数
     */
    validate<Record extends ActiveHashRecord>(model: Queryable<Record>, validations: ValidationsFunction<Record>): void;
    /** バリデートで検出されたエラーメッセージ */
    errorMessages(): string[];
}
/** バリデーションのインスタンス */
export declare const activeHashValidation: ActiveHashValidation;
/** モデルをバリデートする */
export declare const validateModel: <Record_1 extends ActiveHashRecord>(model: Queryable<Record_1>, validations: ValidationsFunction<Record_1>) => void;
